package mi.hdm.recipes;

import mi.hdm.mealPlan.MealPlan;

import java.util.Map;

public class NutritionCalculator {
    /**
     * Method to calculate the nutrition table for a recipe out of its ingredients.
     *
     * @return the nutrition table for this recipe based on its ingredients. All nutrition values are added up.
     */
    public static NutritionTable calculateNutritionTable(Map<RecipeComponent, Integer> ingredients) {
        double totalCals = 0,
                totalCarbs = 0,
                totalFats = 0,
                totalProteins = 0,
                totalFibers = 0,
                totalSalt = 0;

        for (RecipeComponent entry : ingredients.keySet()) {
            final Map<Nutrition, Double> nutritionTable = entry.getNutritionTable().getTable();

            totalCals += nutritionTable.get(Nutrition.CALORIES) * ingredients.get(entry) / 100;
            totalCarbs += nutritionTable.get(Nutrition.CARBS) * ingredients.get(entry) / 100;
            totalFats += nutritionTable.get(Nutrition.FAT) * ingredients.get(entry) / 100;
            totalProteins += nutritionTable.get(Nutrition.PROTEINS) * ingredients.get(entry) / 100;
            totalFibers += nutritionTable.get(Nutrition.FIBERS) * ingredients.get(entry) / 100;
            totalSalt += nutritionTable.get(Nutrition.SALT) * ingredients.get(entry) / 100;
        }

        return new NutritionTable(totalCals, totalCarbs, totalFats, totalProteins, totalFibers, totalSalt);
    }

    public static NutritionTable calculateNutritionTable(MealPlan mealPlan) {
        return null;
    }
}
