package mi.hdm.recipes;

import mi.hdm.exceptions.InvalidRecipeException;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

public class Recipe implements RecipeComponent {
    private Map<RecipeComponent, Integer> ingredients;
    private String name;
    private String description;
    private List<String> preparation;
    private List<Category> categories;
    private Integer preparationTimeMins;
    private NutritionTable nutritionTable;
    private final LocalDateTime creationTime;

    public Recipe(
            Map<RecipeComponent, Integer> ingredients,
            String name,
            String description,
            List<String> preparation,
            List<Category> categories,
            Integer preparationTimeMins) {
        this.ingredients = ingredients;
        this.name = name;
        this.description = description;
        this.preparation = preparation;
        this.categories = categories;
        this.preparationTimeMins = preparationTimeMins;
        nutritionTable = NutritionCalculator.calculateNutritionTable(ingredients);

        creationTime = LocalDateTime.now();
    }

    public void setName(String name) {
        if (name == null || name.equals("")) {
            throw new InvalidRecipeException("Cannot set name to " + name);
        }
        this.name = name;
    }

    public String getName() {
        return name;
    }

    public String getDescription() {
        return description;
    }

    public void setDescription(String description) {
        this.description = description;
    }

    public List<String> getPreparation() {
        return preparation;
    }

    public void setPreparation(List<String> preparation) {
        this.preparation = preparation;
    }

    public List<Category> getCategories() {
        return categories;
    }

    public void setCategories(List<Category> categories) {
        this.categories = categories;
    }

    public void addCategory(Category category) {
        categories.add(category);
    }

    public Integer getPreparationTimeMins() {
        return preparationTimeMins;
    }

    public void setPreparationTimeMins(int preparationTimeMins) {
        if (preparationTimeMins < 0) {
            throw new InvalidRecipeException("PreparationTime must be a positive value");
        }
        this.preparationTimeMins = preparationTimeMins;
    }

    public LocalDateTime getCreationTime() {
        return creationTime;
    }

    public void setNutritionTable(NutritionTable nutritionTable) {
        if (nutritionTable == null) {
            throw new InvalidRecipeException("Nutrition Table does not exist");
        }
        this.nutritionTable = nutritionTable;
    }

    public NutritionTable getNutritionTable() {
        return nutritionTable;
    }
}
